@@ -24,12 +24,12 @@ NULL
 }
 
 
-##' Base class
-##'
-##' For \code{GTree}, there are extra reference methods:
-##' \code{set_multiple} to set whether multiple or single selection is
-##' being used.
-##' @param ... passed to constructor
+## Base class
+##
+## For \code{GTree}, there are extra reference methods:
+## \code{set_multiple} to set whether multiple or single selection is
+## being used.
+## @param ... passed to constructor
 GTreeBase <- setRefClass("GTreeBase",
                          contains="GWidget",
                          fields=list(
@@ -90,6 +90,7 @@ GTreeBase <- setRefClass("GTreeBase",
                              view_col <- gtkTreeViewColumnNew()
                              view_col$setResizable(TRUE)
                              cellrenderer <- gtkCellRendererText()
+                             view_col$setSortColumnId(0)
                              view_col$PackStart(cellrenderer, TRUE)
                              cellrenderer['xalign'] = 0
                              ##
@@ -105,6 +106,8 @@ GTreeBase <- setRefClass("GTreeBase",
                              ## now add columns,
                              f <- function(x, i) {
                                treeview_col <- make_treeview_column(x, i - 1, .self)
+                               treeview_col$setResizable(TRUE)
+                               treeview_col$setSortColumnId(i - 1)
                                widget$insertColumn(treeview_col, pos = -1) # at end
                              }
                              mapply(f, items, seq_len(ncol(items)))
@@ -220,6 +223,9 @@ GTreeBase <- setRefClass("GTreeBase",
                        add_handler_changed=function(handler, action=NULL, ...) {
                          add_handler("row-activated", handler, action=action, ...)
                        },
+                             add_handler_clicked=function(handler, action=NULL, ...) {
+                                 add_handler_button_release(handler, action=action, ...)
+                             },
                        ## Some extra methods
                        clear_selection=function() {
                          widget$getSelection()$unselectAll()
@@ -229,12 +235,12 @@ GTreeBase <- setRefClass("GTreeBase",
 
 
 
-##' Base class
-##'
-##' For \code{GTree}, there are extra reference methods:
-##' \code{set_multiple} to set whether multiple or single selection is
-##' being used.
-##' @param ... passed to constructor
+## Base class
+##
+## For \code{GTree}, there are extra reference methods:
+## \code{set_multiple} to set whether multiple or single selection is
+## being used.
+## @param ... passed to constructor
 GTree <- setRefClass("GTree",
                      contains="GTreeBase",
                      fields=list(
@@ -364,6 +370,8 @@ GTree <- setRefClass("GTree",
                          these <- setdiff(seq_along(items), not_these)
                          sapply(these, function(col) {
                            treeview_col <- make_treeview_column(items[,col], col - 1L, .self)
+                           treeview_col$setResizable(TRUE)
+                           treeview_col$setSortColumnId(col - 1)
                            widget$insertColumn(treeview_col, pos = -1) # at end
                           })
                         },
@@ -371,6 +379,7 @@ GTree <- setRefClass("GTree",
                          "Make column for key and icons, if present"
                          view_col <- gtkTreeViewColumnNew()
                          view_col$setResizable(TRUE)
+                         view_col$setSortColumnId(0)                         
                          if(!is.null(icon_col)) {
                             cellrenderer <- gtkCellRendererPixbufNew()
                             view_col$PackStart(cellrenderer, FALSE)
